Class: Google::Cloud::MediaTranslation::V1beta1::StreamingTranslateSpeechResult::TextTranslationResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/mediatranslation/v1beta1/media_translation.rb

Overview

Text translation result.

Instance Attribute Summary collapse

Instance Attribute Details

#is_final::Boolean (readonly)

Output only. If false, this StreamingTranslateSpeechResult represents an interim result that may change. If true, this is the final time the translation service will return this particular StreamingTranslateSpeechResult, the streaming translator will not return any further hypotheses for this portion of the transcript and corresponding audio.

Returns:

  • (::Boolean)

    Output only. If false, this StreamingTranslateSpeechResult represents an interim result that may change. If true, this is the final time the translation service will return this particular StreamingTranslateSpeechResult, the streaming translator will not return any further hypotheses for this portion of the transcript and corresponding audio.



161
162
163
164
# File 'proto_docs/google/cloud/mediatranslation/v1beta1/media_translation.rb', line 161

class TextTranslationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#translation::String (readonly)

Returns Output only. The translated sentence.

Returns:

  • (::String)

    Output only. The translated sentence.



161
162
163
164
# File 'proto_docs/google/cloud/mediatranslation/v1beta1/media_translation.rb', line 161

class TextTranslationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end